@@ -14,3 +14,8 @@
 ##' @docType data
 ##' @keywords datasets
 NULL
+
+##' Name of the ChIPseeker cache environment (internal static variable)
+##' @format character vector 
+ChIPseekerCache <- "ChIPseekerEnv"
+
