@@ -51,6 +51,7 @@ getPromoters <- function(TxDb=NULL,
 ##' @param type one of "start_site", "end_site", "body"
 ##' @return GRanges object
 ##' @import BiocGenerics IRanges GenomicRanges
+##' @importFrom yulab.utils get_cache_item
 ##' @author Guangchuang Yu, Ming L
 ##' @export
 getBioRegion <- function(TxDb=NULL,
@@ -63,8 +64,8 @@ getBioRegion <- function(TxDb=NULL,
   type <- match.arg(type, c("start_site", "end_site", "body"))
   
   TxDb <- loadTxDb(TxDb)
-  .ChIPseekerEnv(TxDb)
-  ChIPseekerEnv <- get("ChIPseekerEnv", envir=.GlobalEnv)
+  .ChIPseekerEnv(TxDb, item = ChIPseekerCache)
+  # ChIPseekerEnv <- get("ChIPseekerEnv", envir=.GlobalEnv)
   
   label <- make_label(type = type, by = by)
   
@@ -74,12 +75,14 @@ getBioRegion <- function(TxDb=NULL,
   }
   
   if (by == "exon") {
-    exonList <- get_exonList(ChIPseekerEnv)
+    # exonList <- get_exonList(ChIPseekerEnv)
+    exonList <- get_exonList(item = ChIPseekerCache)
     regions <-  unlist(exonList)
   }
   
   if (by == "intron") {
-    intronList <- get_intronList(ChIPseekerEnv)
+    # intronList <- get_intronList(ChIPseekerEnv)
+    intronList <- get_intronList(item = ChIPseekerCache)
     regions <- unlist(intronList)
   }
   
